@@ -7,11 +7,6 @@
 // We also explicitely grant the right to link this code
 // with the OpenH323 library.
 //
-// History:
-// 	990924	initial version (Jan Willamowius)
-//	991025	added command thread (Ashley Unitt)
-//	030511  redesign based on new architecture (cwhuang)
-//
 //////////////////////////////////////////////////////////////////
 
 #if defined(_WIN32) && (_MSC_VER <= 1200)
@@ -863,19 +858,14 @@ bool StatusClient::WriteString(
 	if (CanFlush())
 	    Flush();
 
-	if (m_isFilteringActive == false)
-	    return WriteData(msg, msg.GetLength());
-
-	// If we use filters check if the message is to be ignored
-	if (IsExcludeMessage(msg))
-	    return true;
+	if (m_isFilteringActive && (IsExcludeMessage(msg) || !IsIncludeMessage(msg)))
+	    return false;
 	
-	// If we use filters check if the message is to be shown
-	if (IsIncludeMessage(msg))
-	    return WriteData(msg, msg.GetLength());
+	if (!WriteData(msg, msg.GetSize()))
+	    while (CanFlush())
+		Flush();
 
-	// Otherwise, do not show the message at all
-	return true;
+	return IsOpen();
 }
 
 /*
@@ -1297,6 +1287,7 @@ void StatusClient::ExecCommand(
 			RasServer::Instance()->GetVirtualQueue()->RouteToAlias(args[1], "", args[2], args[3].AsUnsigned(), "");
 		} else if (args.GetSize() == 5) {
 			args[4].Replace("-", " ", true);
+			args[4] = args[4].Trim();
 			RasServer::Instance()->GetVirtualQueue()->RouteToAlias(args[1], "", args[2], args[3].AsUnsigned(), args[4]);
 		} else {
 			WriteString("Syntax Error: RouteToAlias TARGET_ALIAS CALLING_ENDPOINT_ID CRV [CALLID]\r\n");
@@ -1308,6 +1299,7 @@ void StatusClient::ExecCommand(
 			RasServer::Instance()->GetVirtualQueue()->RouteToAlias(args[1], args[2], args[3], args[4].AsUnsigned(), "");
 		} else if (args.GetSize() == 6) {
 			args[5].Replace("-", " ", true);
+			args[5] = args[5].Trim();
 			RasServer::Instance()->GetVirtualQueue()->RouteToAlias(args[1], args[2], args[3], args[4].AsUnsigned(), args[5]);
 		} else {
 			WriteString("Syntax Error: RouteToGateway TARGET_ALIAS TARGET_IP CALLING_ENDPOINT_ID CRV [CALLID]\r\n");
@@ -1319,6 +1311,7 @@ void StatusClient::ExecCommand(
 			RasServer::Instance()->GetVirtualQueue()->RouteReject(args[1], args[2].AsUnsigned(), "");
 		} else if (args.GetSize() == 4) {
 			args[3].Replace("-", " ", true);
+			args[3] = args[3].Trim();
 			RasServer::Instance()->GetVirtualQueue()->RouteReject(args[1], args[2].AsUnsigned(), args[3]);
 		} else {
 			WriteString("Syntax Error: RouteReject CALLING_ENDPOINT_ID CRV [CALLID]\r\n");
