@@ -275,6 +275,8 @@ bool Neighbor::SetProfile(const PString & name, const H323TransportAddress & add
 		m_sendPrefixes[p[0]] = (p.GetSize() > 1) ? p[1].AsInteger() : 1;
 	}
  
+  SetForwardedInfo(LRQFeaturesSection);
+
   return true;
 
 }
@@ -357,12 +359,23 @@ bool Neighbor::CheckReply(RasMsg *ras) const
 {
 	if( ras->IsFrom(GetIP(), 0 /*m_port*/) )
 		return true;
-	else {
-		const H225_NonStandardParameter *params = ras->GetNonStandardParam();
-		return params
-			?(strncmp(m_id, params->m_data.AsString(), m_id.GetLength()) == 0)
-			:false;
+
+	const H225_NonStandardParameter *param = ras->GetNonStandardParam();
+	if (param == NULL)
+		return false;
+
+	int iec = Toolkit::iecUnknown;
+	if (param->m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_h221NonStandard) {
+		iec = Toolkit::Instance()->GetInternalExtensionCode((const H225_H221NonStandard&)param->m_nonStandardIdentifier);
+	} else if (param->m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_object) {
+		const PASN_ObjectId &oid = param->m_nonStandardIdentifier;
+		if (oid.GetDataLength() == 0)
+			iec = Toolkit::iecNeighborId;
 	}
+	
+	return iec == Toolkit::iecNeighborId
+		? strncmp(m_id, param->m_data.AsString(), m_id.GetLength()) == 0
+		: false;
 }
 
 bool Neighbor::IsAcceptable(RasMsg *ras) const
@@ -449,6 +462,11 @@ bool GnuGK::OnSendingLRQ(H225_LocationRequest & lrq, const AdmissionRequest & re
 	lrq.IncludeOptionalField(H225_LocationRequest::e_gatekeeperIdentifier);
 	lrq.m_gatekeeperIdentifier = Toolkit::GKName();
 	lrq.IncludeOptionalField(H225_LocationRequest::e_nonStandardData);
+	lrq.m_nonStandardData.m_nonStandardIdentifier.SetTag(H225_NonStandardIdentifier::e_h221NonStandard);
+	H225_H221NonStandard &t35 = lrq.m_nonStandardData.m_nonStandardIdentifier;
+	t35.m_t35CountryCode = Toolkit::t35cPoland;
+	t35.m_manufacturerCode = Toolkit::t35mGnuGk;
+	t35.m_t35Extension = Toolkit::t35eNeighborId;
 	lrq.m_nonStandardData.m_data.SetValue(m_id);
 
 	const H225_AdmissionRequest & arq = request.GetRequest();
@@ -466,6 +484,11 @@ bool GnuGK::OnSendingLRQ(H225_LocationRequest & lrq, const SetupRequest & reques
 	lrq.IncludeOptionalField(H225_LocationRequest::e_gatekeeperIdentifier);
 	lrq.m_gatekeeperIdentifier = Toolkit::GKName();
 	lrq.IncludeOptionalField(H225_LocationRequest::e_nonStandardData);
+	lrq.m_nonStandardData.m_nonStandardIdentifier.SetTag(H225_NonStandardIdentifier::e_h221NonStandard);
+	H225_H221NonStandard &t35 = lrq.m_nonStandardData.m_nonStandardIdentifier;
+	t35.m_t35CountryCode = Toolkit::t35cPoland;
+	t35.m_manufacturerCode = Toolkit::t35mGnuGk;
+	t35.m_t35Extension = Toolkit::t35eNeighborId;
 	lrq.m_nonStandardData.m_data.SetValue(m_id);
 
 	const H225_Setup_UUIE & setup = request.GetRequest();
@@ -484,6 +507,11 @@ bool GnuGK::OnSendingLRQ(H225_LocationRequest & lrq, const FacilityRequest & /*r
 	lrq.IncludeOptionalField(H225_LocationRequest::e_gatekeeperIdentifier);
 	lrq.m_gatekeeperIdentifier = Toolkit::GKName();
 	lrq.IncludeOptionalField(H225_LocationRequest::e_nonStandardData);
+	lrq.m_nonStandardData.m_nonStandardIdentifier.SetTag(H225_NonStandardIdentifier::e_h221NonStandard);
+	H225_H221NonStandard &t35 = lrq.m_nonStandardData.m_nonStandardIdentifier;
+	t35.m_t35CountryCode = Toolkit::t35cPoland;
+	t35.m_manufacturerCode = Toolkit::t35mGnuGk;
+	t35.m_t35Extension = Toolkit::t35eNeighborId;
 	lrq.m_nonStandardData.m_data.SetValue(m_id);
 	
 	lrq.IncludeOptionalField(H225_LocationRequest::e_canMapAlias);
@@ -526,8 +554,8 @@ bool CiscoGK::OnSendingLRQ(H225_LocationRequest &lrq, const AdmissionRequest &re
 	lrq.IncludeOptionalField(H225_LocationRequest::e_nonStandardData);
 	lrq.m_nonStandardData.m_nonStandardIdentifier.SetTag(H225_NonStandardIdentifier::e_h221NonStandard);
 	H225_H221NonStandard & h221 = lrq.m_nonStandardData.m_nonStandardIdentifier;
-	h221.m_manufacturerCode = 18;
-	h221.m_t35CountryCode = 181;
+	h221.m_manufacturerCode = Toolkit::t35mCisco;
+	h221.m_t35CountryCode = Toolkit::t35cUSA;
 	h221.m_t35Extension = 0;
 	
 	PPER_Stream buff;
@@ -546,7 +574,7 @@ bool CiscoGK::OnSendingLRQ(H225_LocationRequest &lrq, const LocationRequest &req
 	if (lrq.HasOptionalField(H225_LocationRequest::e_nonStandardData)
 			&& lrq.m_nonStandardData.GetTag() == H225_NonStandardIdentifier::e_h221NonStandard) {
 		const H225_H221NonStandard &h221 = lrq.m_nonStandardData.m_nonStandardIdentifier;
-		if (h221.m_manufacturerCode == 18 && h221.m_t35CountryCode == 181)
+		if (h221.m_manufacturerCode == Toolkit::t35mCisco && h221.m_t35CountryCode == Toolkit::t35cUSA)
 			return true;
 			
 		lrq.RemoveOptionalField(H225_LocationRequest::e_nonStandardData);
@@ -565,8 +593,8 @@ bool CiscoGK::OnSendingLRQ(H225_LocationRequest &lrq, const LocationRequest &req
 	lrq.IncludeOptionalField(H225_LocationRequest::e_nonStandardData);
 	lrq.m_nonStandardData.m_nonStandardIdentifier.SetTag(H225_NonStandardIdentifier::e_h221NonStandard);
 	H225_H221NonStandard & h221 = lrq.m_nonStandardData.m_nonStandardIdentifier;
-	h221.m_manufacturerCode = 18;
-	h221.m_t35CountryCode = 181;
+	h221.m_manufacturerCode = Toolkit::t35mCisco;
+	h221.m_t35CountryCode = Toolkit::t35cUSA;
 	h221.m_t35Extension = 0;
 	
 	PPER_Stream buff;
@@ -611,8 +639,8 @@ bool CiscoGK::OnSendingLRQ(H225_LocationRequest &lrq, const SetupRequest &req)
 	lrq.IncludeOptionalField(H225_LocationRequest::e_nonStandardData);
 	lrq.m_nonStandardData.m_nonStandardIdentifier.SetTag(H225_NonStandardIdentifier::e_h221NonStandard);
 	H225_H221NonStandard & h221 = lrq.m_nonStandardData.m_nonStandardIdentifier;
-	h221.m_manufacturerCode = 18;
-	h221.m_t35CountryCode = 181;
+	h221.m_manufacturerCode = Toolkit::t35mCisco;
+	h221.m_t35CountryCode = Toolkit::t35cUSA;
 	h221.m_t35Extension = 0;
 	
 	PPER_Stream buff;
@@ -642,7 +670,7 @@ bool CiscoGK::CheckReply(RasMsg *msg) const
 		return false;
 	
 	H225_H221NonStandard &h221 = nonStandardData->m_nonStandardIdentifier;
-	if (h221.m_manufacturerCode != 18 || h221.m_t35CountryCode != 181)
+	if (h221.m_manufacturerCode != Toolkit::t35mCisco || h221.m_t35CountryCode != Toolkit::t35cUSA)
 		return false;
 	
 	PPER_Stream strm(nonStandardData->m_data);
@@ -755,7 +783,7 @@ bool LRQRequester::Send(NeighborList::List & neighbors, Neighbor *requester)
 	if (m_requests.empty())
 		return false;
 
-	m_retry = 2; // TODO: configurable
+	m_retry = GkConfig()->GetInteger(LRQFeaturesSection, "SendRetries", 2); 
 	PTRACE(2, "NB\t" << m_requests.size() << " LRQ(s) sent");
 	return true;
 }
@@ -772,6 +800,7 @@ bool LRQRequester::Send(Neighbor * nb)
 		return false;
 	}
 
+	m_retry = GkConfig()->GetInteger(LRQFeaturesSection, "SendRetries", 2);
 	PTRACE(2, "SRV\tLRQ sent to " << nb->GetIP());
 	return true;
 }
@@ -797,17 +826,28 @@ void LRQRequester::Process(RasMsg *ras)
 	PWaitAndSignal lock(m_rmutex);
 	for (Queue::iterator iter = m_requests.begin(); iter != m_requests.end(); ++iter) {
 		Request & req = iter->second;
-		if (req.m_neighbor->CheckReply(ras)) {
+		if (req.m_neighbor->CheckReply(ras) ||
+			Toolkit::AsBool(GkConfig()->GetString(LRQFeaturesSection, "AcceptNonNeighborLCF", "0"))) {
 			PTRACE(5,"NB\tReceived "<<ras->GetTagName()<<" message matched"
 				<<" pending LRQ for neighbor "<<req.m_neighbor->GetId()
 				<<':'<<req.m_neighbor->GetIP()
 				);
 			unsigned tag = ras->GetTag();
 			if (tag == H225_RasMessage::e_requestInProgress) {
-				if (H225_NonStandardParameter *params = ras->GetNonStandardParam()) {
-					PStringArray param(params->m_data.AsString().Tokenise(":", false));
-					if (param.GetSize() > 1)
-						req.m_count += param[1].AsInteger();
+				if (H225_NonStandardParameter *param = ras->GetNonStandardParam()) {
+					int iec = Toolkit::iecUnknown;
+					if (param->m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_h221NonStandard) {
+						iec = Toolkit::Instance()->GetInternalExtensionCode((const H225_H221NonStandard&)param->m_nonStandardIdentifier);
+					} else if (param->m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_object) {
+						PASN_ObjectId &oid = param->m_nonStandardIdentifier;
+						if (oid.GetDataLength() == 0)
+							iec = Toolkit::iecNeighborId;
+					}
+					if (iec == Toolkit::iecNeighborId) {
+						PStringArray ttl(param->m_data.AsString().Tokenise(":", false));
+						if (ttl.GetSize() > 1)
+							req.m_count += ttl[1].AsInteger();
+					}
 				}
 				RasRequester::Process(ras);
 			} else if (tag == H225_RasMessage::e_locationConfirm) {
@@ -1081,7 +1121,9 @@ bool NeighborPolicy::OnRequest(AdmissionRequest & arq_obj)
 			Route route(m_name, lcf->m_callSignalAddress);
 			route.m_routeId = request.GetNeighborUsed();
 			route.m_flags |= Route::e_toNeighbor;
-			if (lcf->HasOptionalField(H225_LocationConfirm::e_destinationInfo)) {
+			if ((lcf->HasOptionalField(H225_LocationConfirm::e_destinationInfo))
+				&& (lcf->m_destinationInfo.GetSize() > 0)) 
+			{
 				arq_obj.SetAliases(lcf->m_destinationInfo);
 				arq_obj.SetFlag(Routing::AdmissionRequest::e_aliasesChanged);
 			}
@@ -1126,10 +1168,25 @@ bool NeighborPolicy::OnRequest(LocationRequest & lrq_obj)
 			H225_RequestInProgress & rip = (*ras)->m_replyRAS;
 			rip.m_requestSeqNum = ras->GetSeqNum();
 			rip.m_delay = m_neighborTimeout;
-			if (H225_NonStandardParameter *params = ras->GetNonStandardParam()) {
-				PString data = params->m_data.AsString() + ":" + PString(request.GetReqNumber());
-				rip.IncludeOptionalField(H225_RequestInProgress::e_nonStandardData);
-				rip.m_nonStandardData.m_data.SetValue(data);
+			if (H225_NonStandardParameter *param = ras->GetNonStandardParam()) {
+				int iec = Toolkit::iecUnknown;
+				if (param->m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_h221NonStandard) {
+					iec = Toolkit::Instance()->GetInternalExtensionCode((const H225_H221NonStandard&)param->m_nonStandardIdentifier);
+				} else if (param->m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_object) {
+					PASN_ObjectId &oid = param->m_nonStandardIdentifier;
+					if (oid.GetDataLength() == 0)
+						iec = Toolkit::iecNeighborId;
+				}
+				if (iec == Toolkit::iecNeighborId) {
+					PString data = param->m_data.AsString() + ":" + PString(request.GetReqNumber());
+					rip.IncludeOptionalField(H225_RequestInProgress::e_nonStandardData);
+					rip.m_nonStandardData.m_nonStandardIdentifier.SetTag(H225_NonStandardIdentifier::e_h221NonStandard);
+					H225_H221NonStandard &t35 = rip.m_nonStandardData.m_nonStandardIdentifier;
+					t35.m_t35CountryCode = Toolkit::t35cPoland;
+					t35.m_manufacturerCode = Toolkit::t35mGnuGk;
+					t35.m_t35Extension = Toolkit::t35eNeighborId;
+					rip.m_nonStandardData.m_data.SetValue(data);
+				}
 			}
 			return true;
 		}
@@ -1146,7 +1203,9 @@ bool NeighborPolicy::OnRequest(LocationRequest & lrq_obj)
 				// canMapAlias: copy new destination if changed
 				if (lrq_obj.GetRequest().HasOptionalField(H225_LocationRequest::e_canMapAlias)
 					&& lrq_obj.GetRequest().m_canMapAlias
-					&& lrq_obj.GetRequest().m_destinationInfo != lcf->m_destinationInfo) {
+					&& lcf->HasOptionalField(H225_LocationConfirm::e_destinationInfo)
+				    && (lcf->m_destinationInfo.GetSize() > 0)
+					&& (lrq_obj.GetRequest().m_destinationInfo != lcf->m_destinationInfo)) {
 					lrq_obj.GetRequest().m_destinationInfo = lcf->m_destinationInfo;
 					lrq_obj.SetFlag(RoutingRequest::e_aliasesChanged);
 				}
@@ -1170,6 +1229,13 @@ bool NeighborPolicy::OnRequest(SetupRequest & setup_obj)
 			route.m_flags |= Route::e_toNeighbor;
 			setup_obj.AddRoute(route);
 			CopyCryptoTokens(lcf, setup_obj.GetRequest());
+			// canMapAlias: adjust new destination
+			if (lcf->HasOptionalField(H225_LocationConfirm::e_destinationInfo)
+				&& (lcf->m_destinationInfo.GetSize() > 0)
+				&& (setup_obj.GetRequest().m_destinationAddress != lcf->m_destinationInfo)) {
+				setup_obj.GetRequest().m_destinationAddress = lcf->m_destinationInfo;
+				setup_obj.SetFlag(RoutingRequest::e_aliasesChanged);
+			}
 			return true;
 		}
 	}
@@ -1215,49 +1281,9 @@ bool SRVPolicy::FindByAliases(
 {
 	for (PINDEX i = 0; i < aliases.GetSize(); ++i) {
 		PString alias(AsString(aliases[i], FALSE));
-		PINDEX at = alias.Find('@');
+	    if (alias.GetLength() == 0) continue;
 
 	// DNS SRV Record lookup
-		if (at != P_MAX_INDEX) {
-		   PString number = alias;
-		   if (number.Left(5) != "h323:") 
-			  number = "h323:" + number;	  
-					
-   // CS SRV Lookup
-		   PStringList str;
-		   if (PDNS::LookupSRV(number,"_h323cs._tcp.",str)) {
-			   for (PINDEX j=0; j<str.GetSize(); j++) {
-				 PTRACE(4, "ROUTING\tDNS SRV converted remote party " << alias << " to " << str[j]);
-		         H225_TransportAddress dest;
-				 PINDEX in = str[j].Find('@');
-				 PString domain = str[j].Mid(in + 1);
-		         if (GetTransportAddress(domain, GK_DEF_ENDPOINT_SIGNAL_PORT, dest)) {
-			       PIPSocket::Address addr;
-			       if (!(GetIPFromTransportAddr(dest, addr) && addr.IsValid()))
-				                    continue;
-			       Route route(m_name, dest);
-			       route.m_destEndpoint = RegistrationTable::Instance()->FindBySignalAdr(dest);
-			       request.AddRoute(route);
-			       request.SetFlag(RoutingRequest::e_aliasesChanged);	
-				 }
-			   }
-			 // remove the domain name 
-		     H323SetAliasAddress(alias.Left(at), aliases[i]);
-		     return true;
-		   }
-		}
-	}
-	return SRVPolicy::FindByAliases((LocationRequest&)request, aliases);
-}
-
-
-bool SRVPolicy::FindByAliases(LocationRequest & request, H225_ArrayOf_AliasAddress & aliases)
-{ 
-
-	// DNS SRV Record lookup
-	for (PINDEX i = 0; i < aliases.GetSize(); ++i) {
-		PString alias(AsString(aliases[i], FALSE));
-
 		PString number;
 		PString domain;
 		PINDEX at = alias.Find('@');
@@ -1268,41 +1294,68 @@ bool SRVPolicy::FindByAliases(LocationRequest & request, H225_ArrayOf_AliasAddre
 		   number = "h323:" + alias;
 		   domain = alias.Mid(at+1);
 		}
-					
-        PStringList str;
+	
 		// LS Record lookup
-        if (PDNS::LookupSRV(number,"_h323ls._udp.",str)) {
-          for (PINDEX i=0; i<str.GetSize(); i++) {
-            PINDEX at = str[i].Find('@');
-            PString ipaddr = str[i].Mid(at + 1);
-            PTRACE(4, "ROUTING\tDNS SRV LRQ located domain " << domain << " at " << ipaddr);
-            H323TransportAddress addr = H323TransportAddress(ipaddr);
+		PStringList ls;
+			if (PDNS::LookupSRV(number,"_h323ls._udp.",ls)) {
+			 for (PINDEX i=0; i<ls.GetSize(); i++) {
+				PINDEX at = ls[i].Find('@');
+				PString ipaddr = ls[i].Mid(at + 1);
+				PTRACE(4, "ROUTING\tSRV LS located domain " << domain << " at " << ipaddr);
+				H323TransportAddress addr = H323TransportAddress(ipaddr);
 
-			// Create a SRV gatekeeper object
-			GnuGK * nb = new GnuGK();
-			if (!nb->SetProfile(domain,addr)) {
-				PTRACE(4, "ROUTING\tERROR setting SRV neighbor profile " << domain << " at " << addr);
-				return false;
-			}
+				// Create a SRV gatekeeper object
+				GnuGK * nb = new GnuGK();
+				if (!nb->SetProfile(domain,addr)) {
+					PTRACE(4, "ROUTING\tERROR setting SRV neighbor profile " << domain << " at " << addr);
+					return false;
+				}
 
-			int m_neighborTimeout = GkConfig()->GetInteger(LRQFeaturesSection, "NeighborTimeout", 5) * 100;
+				int m_neighborTimeout = GkConfig()->GetInteger(LRQFeaturesSection, "NeighborTimeout", 5) * 100;
 
-			// Send LRQ to retreive callers signalling address 
-	        LRQSender<AdmissionRequest> functor((AdmissionRequest &)request);
-	        LRQRequester Request(functor);
-	        if (Request.Send(nb)) {
-		        if (H225_LocationConfirm *lcf = Request.WaitForDestination(m_neighborTimeout)) {
-			     if (lcf->HasOptionalField(H225_LocationConfirm::e_destinationInfo)) {
-				    Route route(m_name, lcf->m_callSignalAddress);
-			        request.AddRoute(route);
-				    request.SetFlag(Routing::AdmissionRequest::e_aliasesChanged);
-			        return true;
+				// Send LRQ to retreive callers signalling address 
+				LRQSender<AdmissionRequest> functor((AdmissionRequest &)request);
+				LRQRequester Request(functor);
+				if (Request.Send(nb)) {
+					if (H225_LocationConfirm *lcf = Request.WaitForDestination(m_neighborTimeout)) {
+							Route route(m_name, lcf->m_callSignalAddress);
+							request.AddRoute(route);
+							request.SetFlag(RoutingRequest::e_aliasesChanged);
+							return true;
+				    }
+				}
+				PTRACE(4, "ROUTING\tDNS SRV LRQ Error for " << domain << " at " << ipaddr);
+			 }
+			}  
+
+        // CS SRV Lookup
+		PStringList cs;
+		   if (PDNS::LookupSRV(number,"_h323cs._tcp.",cs)) {
+			   for (PINDEX j=0; j<cs.GetSize(); j++) {
+				 PTRACE(4, "ROUTING\tSRV CS converted remote party " << alias << " to " << cs[j]);
+		         H225_TransportAddress dest;
+				 PINDEX in = cs[j].Find('@');
+                 PString dom = cs[j].Mid(in+1);
+		         if (GetTransportAddress(dom, GK_DEF_ENDPOINT_SIGNAL_PORT, dest)) {
+			       PIPSocket::Address addr;
+			       if (!(GetIPFromTransportAddr(dest, addr) && addr.IsValid()))
+				                    continue;
+			       Route route(m_name, dest);
+			       route.m_destEndpoint = RegistrationTable::Instance()->FindBySignalAdr(dest);
+			       request.AddRoute(route);
+			       request.SetFlag(RoutingRequest::e_aliasesChanged);	
 				 }
-		       }
-	        }
-		  }
-		} 
-	}
+			   }
+		     return true;
+		   } 
+	} 
+  return false; 
+}
+
+
+bool SRVPolicy::FindByAliases(LocationRequest & request, H225_ArrayOf_AliasAddress & aliases)
+{ 
+    PTRACE(4, "ROUTING\tPolicy SRV not supported for LRQ");
 	return false;  
 }
 #endif
