@@ -7,15 +7,10 @@
 // We also explicitely grant the right to link this code
 // with the OpenH323 library.
 //
-// History:
-// 	990500	initial version (Xiang Ping Chen, Rajat Todi, Joe Metzger)
-//	990600	ported to OpenH323 V. 1.08 (Jan Willamowius)
-//	991003	switched to STL (Jan Willamowius)
-//
 //////////////////////////////////////////////////////////////////
 
 #ifndef RASTBL_H
-#define RASTBL_H "@(#) $Id: RasTbl.h,v 1.107 2006/12/06 16:34:04 zvision Exp $"
+#define RASTBL_H "@(#) $Id: RasTbl.h,v 1.116.2.1 2007/04/26 19:29:48 willamowius Exp $"
 
 #include <list>
 #include <vector>
@@ -210,19 +205,6 @@ public:
 		long callDurationLimit /// call duration limit (-1 if not set)
 		);
 
-	/** @return
-	    Maximum call capacity for this endpoint. -1 if there is not capacity
-	    limit set.
-	*/
-	int GetCapacity() const { return m_capacity; }
-	
-	/** Set maximum number of concurrent calls this endpoint can handle.
-	    Pass -1 to disable the limit.
-	*/
-	void SetCapacity(
-		int newCapacity /// max number of concurrent calls, -1 means no limit
-		);
-
 	/** @return
 	    True if the endpoint can handle at least one more concurrent call.
 	*/
@@ -295,8 +277,8 @@ typedef EndpointRec::Ptr endptr;
 
 class GatewayRec : public EndpointRec {
 public:
-	typedef std::vector<std::string>::iterator prefix_iterator;
-	typedef std::vector<std::string>::const_iterator const_prefix_iterator;
+	typedef std::map<std::string, int>::iterator prefix_iterator;
+	typedef std::map<std::string, int>::const_iterator const_prefix_iterator;
 
 	GatewayRec(const H225_RasMessage & completeRAS, bool Permanent=false);
 
@@ -333,7 +315,9 @@ public:
 		/// aliases to be matched (one of them)
 		const H225_ArrayOf_AliasAddress& aliases,
 		/// filled with an index of the matching alias (if found)
-		int& matchedalias
+		int& matchedalias,
+		/// priority of matched prefix
+		int& priority
 		) const;
 
 	//virtual void BuildLCF(H225_LocationConfirm &) const;
@@ -355,6 +339,8 @@ public:
 		int newPriority
 		);
 
+	//void DumpPriorities() const;
+
 private:
 	/// Load gateway specific settings from the config
 	void LoadGatewayConfig();
@@ -364,9 +350,8 @@ private:
 	GatewayRec& operator=(const GatewayRec&);
 
 protected:
-	// strange! can't compile in debug mode, anybody know why??
-	//vector<PString> Prefixes;
-	std::vector<std::string> Prefixes;
+	std::map<std::string, int> Prefixes;
+
 	bool defaultGW;
 	/// priority for this gateway (when more than one gw matches a dialed number)
 	int priority;
@@ -410,7 +395,6 @@ public:
 	endptr FindOZEPBySignalAdr(const H225_TransportAddress &) const;
 	endptr FindByAliases(const H225_ArrayOf_AliasAddress & alias) const;
 	endptr FindEndpoint(const H225_ArrayOf_AliasAddress & alias, bool RoundRobin, bool SearchOuterZone = true);
-	endptr FindEndpoint(const H225_ArrayOf_AliasAddress & alias, bool RoundRobin, bool SearchOuterZone, const std::list<H225_TransportAddress> & ignoreList);
 	void FindEndpoint(
 		const H225_ArrayOf_AliasAddress &aliases,
 		bool roundRobin,
@@ -434,11 +418,6 @@ public:
 
 	PINDEX Size() const { return regSize; }
 
-public:
-  enum enumGatewayFlags {
-                e_SCNType		// "trunk" or "residential"
-  };
-
 private:
 
 	endptr InternalInsertEP(H225_RasMessage &);
@@ -461,7 +440,7 @@ private:
 	        return endptr((Iter != ListToBeFound->end()) ? *Iter : 0);
 	}
 
-	endptr InternalFindEP(const H225_ArrayOf_AliasAddress & alias, std::list<EndpointRec *> *ListToBeFound, bool roundrobin, const std::list<H225_TransportAddress> & ignoreList);
+	endptr InternalFindEP(const H225_ArrayOf_AliasAddress & alias, std::list<EndpointRec *> *ListToBeFound, bool roundrobin);
 	void InternalFindEP(const H225_ArrayOf_AliasAddress & alias, std::list<EndpointRec *> *ListToBeFound, bool roundrobin, std::list<Routing::Route> &routes);
 
 	void GenerateEndpointId(H225_EndpointIdentifier &);
@@ -931,9 +910,6 @@ public:
 	void SetNewRoutes(
 		const std::list<Routing::Route> &routes
 		);
-	void SetFailedRoutes(
-		const std::list<Routing::Route> &routes
-		);
 	const std::list<Routing::Route> &GetNewRoutes() const { return m_newRoutes; }
 	const std::list<Routing::Route> &GetFailedRoutes() const { return m_failedRoutes; }
 	bool MoveToNextRoute();
