@@ -7,9 +7,6 @@
 // We also explicitely grant the right to link this code
 // with the OpenH323 library.
 //
-// History:
-// 	991227  initial version (Torsten Will, mediaWays)
-//
 //////////////////////////////////////////////////////////////////
 
 #if defined(_WIN32) && (_MSC_VER <= 1200)
@@ -307,7 +304,7 @@ bool Toolkit::RouteTable::CreateRouteTable(const PString & extroute)
 		return false;
 	}
 
-	if (!extroute && AsBool(GkConfig()->GetString(ProxySection, "Enable", "0"))) {
+	if (/*!extroute &&*/ AsBool(GkConfig()->GetString(ProxySection, "Enable", "0"))) {
 	  for (PINDEX i = 0; i < r_table.GetSize(); ++i) {
 		if (r_table[i].GetNetwork().IsRFC1918() && r_table[i].GetNetMask().AsString() != "255.255.255.255") {
 		  PString intAddr = r_table[i].GetNetwork().AsString() + "/" + r_table[i].GetNetMask().AsString();
@@ -425,13 +422,17 @@ bool Toolkit::ProxyCriterion::Required(const Address & ip1, const Address & ip2)
 	return m_enable ? (m_networks.empty() || (IsInternal(ip1) != IsInternal(ip2))) : false;
 }
 
-bool Toolkit::ProxyCriterion::IsInternal(const Address & ip) const
+int Toolkit::ProxyCriterion::IsInternal(const Address & ip) const
 {
+   // Return the network Id. Addresses may be on different internal networks
+	int retval = 0;
 	std::vector<NetworkAddress>::const_iterator i = m_networks.begin();
-	while (i != m_networks.end())
+	while (i != m_networks.end()) {
+		retval++;
 		if (ip << *i++)
-			return true;
-	return false;
+			return retval;
+    }
+	return 0;
 }
 
 // class Toolkit::RewriteTool
@@ -512,8 +513,25 @@ bool Toolkit::RewriteTool::RewritePString(PString & s) const
 	// If URL remove the domain if default domain
 	 PINDEX at = s.Find('@');
 	 if (at != P_MAX_INDEX) {
-	   if (s.Mid(at+1) == m_defaultDomain)
-		   s = s.Left(at);
+		 PString num = s.Left(at);
+         // Check if we have a default domain and strip it
+		 if (s.Mid(at+1) == m_defaultDomain) {
+		   PTRACE(2, "\tRewriteDomain: " << s << " to " << num);
+		   s = num;
+		   changed = true;
+		 } else {
+			 // Check if all numeric then is E164 then strip the domain
+			 PINDEX j;
+ 		     for (j = 0; j < num.GetLength(); ++j)
+			       if (!isdigit(num[j]))
+			   	         break;
+
+			 if (j >= num.GetLength()) { // is numeric
+				PTRACE(2, "\tRewriteToE164: " << s << " to " << num);
+                s = num;
+				changed = true;
+			 }
+		 }
 	 }
 
 	// remove trailing character
@@ -895,7 +913,7 @@ void Toolkit::CreateConfig()
 
 void Toolkit::ReloadSQLConfig()
 {
-#if HAS_MYSQL || HAS_PGSQL
+#if HAS_MYSQL || HAS_PGSQL || HAS_FIREBIRD
 	if (m_Config->GetSections().GetStringsIndex("SQLConfig") == P_MAX_INDEX)
 		return;
 
@@ -1184,6 +1202,8 @@ PConfig* Toolkit::ReloadConfig()
 	CapacityControl::Instance()->LoadConfig();
 
 	LoadCauseMap(m_Config);
+
+	LoadReasonMap(m_Config);
 	
 	return m_Config;
 }
@@ -1214,6 +1234,29 @@ void Toolkit::LoadCauseMap(
 		}
 }
 
+// load H.225 reason to Q.931 cause mapping
+void Toolkit::LoadReasonMap(
+	PConfig *cfg
+	)
+{
+	// default to ITU-T Recommendation H.225
+	unsigned DefaultH225ReasonToQ931Cause[] =	{
+		34, 47, 3, 16, 88, 111, 38, 42, 28, 41, 17, 31, 16, 31, 20, 31, 47, 127,
+		31, 31, 31, 127
+	};
+	m_H225ReasonToQ931Cause.assign(&DefaultH225ReasonToQ931Cause[0], &DefaultH225ReasonToQ931Cause[22]);
+
+	for(int reason = 0; reason < H225_ReleaseCompleteReason::e_tunnelledSignallingRejected; reason++) {
+		PString str_reason;
+		str_reason.sprintf("%d", reason);
+		PString cause = cfg->GetString("H225toQ931", str_reason, "");
+		if (!cause.IsEmpty()) {
+			m_H225ReasonToQ931Cause[reason] = cause.AsInteger();
+		}
+	}
+
+}
+
 BOOL Toolkit::MatchRegex(const PString &str, const PString &regexStr)
 {
 	PINDEX pos=0;
@@ -1234,7 +1277,8 @@ BOOL Toolkit::MatchRegex(const PString &str, const PString &regexStr)
 bool Toolkit::RewriteE164(H225_AliasAddress &alias)
 {
 	if ((alias.GetTag() != H225_AliasAddress::e_dialedDigits) &&
-         (alias.GetTag() != H225_AliasAddress::e_h323_ID))
+         (alias.GetTag() != H225_AliasAddress::e_h323_ID) &&
+		 (alias.GetTag() != H225_AliasAddress::e_url_ID))
 		return FALSE;
 
 	PString E164 = ::AsString(alias, FALSE);
@@ -1374,14 +1418,29 @@ Toolkit::GetInternalExtensionCode( const unsigned &country,
 				   const unsigned &extension,
 				   const unsigned &manufacturer) const
 {
-	switch(country) {
+	switch (country) {
 	case t35cOpenOrg:
-		switch(manufacturer) {
+		switch (manufacturer) {
 		case t35mOpenOrg:
-			switch(extension) {
+			switch (extension) {
 				case t35eFailoverRAS: return iecFailoverRAS;
 			}
+			break;
 		}
+		break;
+		
+	case t35cPoland:
+		switch (manufacturer) {
+		case t35mGnuGk:
+			switch (extension) {
+			case t35eNeighborId:
+				return iecNeighborId;
+			case t35eNATTraversal:
+				return iecNATTraversal;
+			}
+			break;
+		}
+		break;
 	}
 
 	// default for all other cases
@@ -1668,3 +1727,14 @@ void Toolkit::SetRerouteCauses(
 {
 	memcpy(causeMap, m_causeMap, 128/8);
 }
+
+
+unsigned Toolkit::MapH225ReasonToQ931Cause(
+	int reason
+	)
+{
+	if( reason < 0 || reason > H225_ReleaseCompleteReason::e_tunnelledSignallingRejected )
+		return 0;
+	else
+		return m_H225ReasonToQ931Cause[reason];
+}
