@@ -7,17 +7,11 @@
 // We also explicitely grant the right to link this code
 // with the OpenH323 library.
 //
-// History:
-// 	990500	initial version (Xiang Ping Chen, Rajat Todi, Joe Metzger)
-//	990600	ported to OpenH323 V. 1.08 (Jan Willamowius)
-//	990702	code cleanup (Jan Willamowius)
-//	990710	working again with OpenH323 V. 1.08 (Jan Willamowius)
-//
 //////////////////////////////////////////////////////////////////
 
 
 #ifndef GK_H
-#define GK_H "@(#) $Id: gk.h,v 1.26 2006/06/26 10:45:18 shorne Exp $"
+#define GK_H "@(#) $Id: gk.h,v 1.27 2007/03/21 22:30:16 willamowius Exp $"
 
 #include "version.h"
 #include <ptlib/pprocess.h>
