@@ -7,15 +7,11 @@
 // We also explicitely grant the right to link this code
 // with the OpenH323 library.
 //
-// History:
-// 	991002	initial version (Jan Willamowius)
-//	990127  moved all to config file (towi)
-//
 //////////////////////////////////////////////////////////////////
 
 
 #ifndef GK_CONST_H
-#define GK_CONST_H "@(#) $Id: gk_const.h,v 1.9 2006/09/16 20:35:43 shorne Exp $"
+#define GK_CONST_H "@(#) $Id: gk_const.h,v 1.13 2007/03/21 22:30:16 willamowius Exp $"
 
 /* all values can be set in the config file, section [Gatekeeper::<InstanceName>]
  * these are just the defaults
@@ -43,10 +39,30 @@ extern const char *H225_ProtocolID;
 #endif
 #endif
 
+///////////////////////////////////////
+//OIDs
+#define GnuGkOID "1.3.6.1.4.1.27938"
+
+// Packetizer H460 Features
+#define OID3 "1.3.6.1.4.1.17090.0.3"  // Presence
+
+#define OID5 "1.3.6.1.4.1.17090.0.5"  // NAT Traversal support   
+#define NATInstOID       "7"   // integer 8 Instruction on how NAT is to be Traversed
+
 #define OID6  "1.3.6.1.4.1.17090.0.6"  // Registration priority & pre-emption
 #define priorityOID  "1"   // integer 8 Priority number highest priority gets registration
 #define preemptOID   "2"   // bool to instruct GK to preempt previous registration
 #define priNotOID    "3"   // bool to notify EP registration RRJ (priority) UCF (higher Priority)
 #define preNotOID    "4"   // bool to notify EP registration RRJ (can preempt) UCF (was preempted)
 
+#define OID7 "1.3.6.1.4.1.17090.0.7"  // NAT Type detection support
+#define localNATOID      "1"    // bool if endpoint is NATed
+#define STUNServOID      "2"    // H225_TransportAddress of STUN Server 
+#define NATTypeOID       "3"    // integer 8 Endpoint NAT Type
+#define NATProxyOID      "4"    // Proxy for NAT support
+#define NATMustProxyOID  "5"    // Media must proxy
+#define remoteNATOID     "6"    // bool if endpoint has remote NAT support
+
+#define GK_DEF_STUN_PORT		3478
+
 #endif
