@@ -12,6 +12,24 @@
  * with the OpenH323 library.
  *
  * $Log: gkacct.cxx,v $
+ * Revision 1.30  2006/04/14 13:56:19  willamowius
+ * call failover code merged
+ *
+ * Revision 1.3  2006/01/19 11:48:45  zvision
+ * New media-ip and codec accounting variables for fast start calls
+ *
+ * Revision 1.2  2005/12/15 12:40:39  willamowius
+ * new accounting variables
+ *
+ * Revision 1.1.1.1  2005/11/21 20:20:00  willamowius
+ *
+ *
+ * Revision 1.4  2005/11/15 19:52:56  jan
+ * Michal v1 (works, but on in routed, not proxy mode)
+ *
+ * Revision 1.29  2005/05/19 16:41:16  zvision
+ * Solaris need explicit std::map
+ *
  * Revision 1.28  2005/04/24 16:39:44  zvision
  * MSVC6.0 compatibility fixed
  *
@@ -115,7 +133,6 @@
 #include "gktimer.h"
 #include "gkacct.h"
 
-using std::map;
 using std::find;
 using std::vector;
 
@@ -203,7 +220,7 @@ GkAcctLogger::Status GkAcctLogger::Log(
 
 void GkAcctLogger::SetupAcctParams(
 	/// CDR parameters (name => value) associations
-	map<PString, PString>& params,
+	std::map<PString, PString>& params,
 	/// call (if any) associated with an accounting event being logged
 	const callptr& call,
 	/// timestamp formatting string
@@ -266,13 +283,28 @@ void GkAcctLogger::SetupAcctParams(
 	params["dest-info"] = call->GetDestInfo();
 	params["Called-Station-Id"] = GetCalledStationId(call);
 	params["Dialed-Number"] = GetDialedNumber(call);
+
+	endptr caller;
+	if (caller = call->GetCallingParty()) {
+		params["caller-epid"] = caller->GetEndpointIdentifier().GetValue();
+	}
+	endptr callee;
+	if (callee = call->GetCalledParty()) {
+		params["callee-epid"] = callee->GetEndpointIdentifier().GetValue();
+	}
+	params["call-attempts"] = PString(call->GetNoCallAttempts());
+	params["last-cdr"] = call->GetNoRemainingRoutes() > 0 ? "0" : "1";
+
+	if (call->GetMediaOriginatingIp(addr))
+		params["media-oip"] = addr.AsString();
+	params["codec"] = call->GetCodec();
 }
 
 PString GkAcctLogger::ReplaceAcctParams(
 	/// parametrized CDR string
 	const PString& cdrStr,
 	/// parameter values
-	const map<PString, PString>& params
+	const std::map<PString, PString>& params
 	) const
 {
 	PString finalCDR((const char*)cdrStr);
@@ -700,7 +732,7 @@ void FileAcct::GetRotateInterval(
 		if (strspn(s, "0123456") == (size_t)s.GetLength()) {
 			m_rotateDay = s.AsInteger();
 		} else {
-			map<PCaselessString, int> dayNames;
+			std::map<PCaselessString, int> dayNames;
 			dayNames["sun"] = 0; dayNames["sunday"] = 0;
 			dayNames["mon"] = 1; dayNames["monday"] = 1;
 			dayNames["tue"] = 2; dayNames["tuesday"] = 2;
@@ -788,7 +820,7 @@ bool FileAcct::GetCDRText(
 	if (m_standardCDRFormat)	
 		cdrString = call->GenerateCDR(m_timestampFormat);
 	else {
-		map<PString, PString> params;
+		std::map<PString, PString> params;
 
 		SetupAcctParams(params, call, m_timestampFormat);
 		cdrString = ReplaceAcctParams(m_cdrString, params);
