@@ -7,10 +7,6 @@
 // We also explicitely grant the right to link this code
 // with the OpenH323 library.
 //
-// History:
-//      2001/09/19      initial version (Chih-Wei Huang)
-//      2003/07/16      revision for thread-safe
-//
 //////////////////////////////////////////////////////////////////
 
 #if defined(_WIN32) && (_MSC_VER <= 1200)
@@ -680,6 +676,10 @@ void GkAuthenticatorList::OnReload()
 	// from another thread
 	WriteLock lock(m_reloadMutex);
 
+	// first destroy old authenticators
+	DeleteObjectsInContainer(m_authenticators);
+	m_authenticators.clear();
+	
 	std::list<GkAuthenticator*> authenticators;	
 	GkAuthenticator *auth;
 	
@@ -690,6 +690,8 @@ void GkAuthenticatorList::OnReload()
 			authenticators.push_back(auth);
 	}
 
+	m_authenticators = authenticators;
+	
 	H225_ArrayOf_AuthenticationMechanism mechanisms;
 	H225_ArrayOf_PASN_ObjectId algorithmOIDs;
 
@@ -850,9 +852,6 @@ void GkAuthenticatorList::OnReload()
 	// now switch to new setting
 	*m_mechanisms = mechanisms;
 	*m_algorithmOIDs = algorithmOIDs;
-	DeleteObjectsInContainer(m_authenticators);
-	m_authenticators.clear();
-	m_authenticators = authenticators;
 }
 
 void GkAuthenticatorList::SelectH235Capability(
@@ -1424,7 +1423,7 @@ bool SimplePasswordAuth::ResolveUserName(
 			}
 			// H235.2
 			if (nestedCryptoToken.GetTag() == H235_CryptoToken::e_cryptoSignedToken) {			
-	          const H235_CryptoToken_cryptoSignedToken & cryptoSignedToken = nestedCryptoToken;;
+	          const H235_CryptoToken_cryptoSignedToken & cryptoSignedToken = nestedCryptoToken;
               H235_SIGNED<H235_EncodedGeneralToken> m_Signed = cryptoSignedToken.m_token;
 			  m_Signed.m_toBeSigned.DecodeSubType(clearToken);
 			  found = true;
@@ -2178,57 +2177,3 @@ namespace { // anonymous namespace
 	GkAuthCreator<AliasAuth> AliasAuthCreator("AliasAuth");
 	GkAuthCreator<PrefixAuth> PrefixAuthCreator("PrefixAuth");
 } // end of anonymous namespace
-
-/* This is OBSOLETE
-#if ((defined(__GNUC__) && __GNUC__ <= 2) && !defined(_WIN32))
-#include <unistd.h>
-#include <procbuf.h>
-
-class ExternalPasswordAuth : public SimplePasswordAuth {
-public:
-	ExternalPasswordAuth(const char *);
-
-private:
-	bool ExternalInit();
-	virtual bool GetPassword(const PString &, PString &);
-
-	PString Program;
-};
-
-// class ExternalPasswordAuth
-ExternalPasswordAuth::ExternalPasswordAuth(const char *name) : SimplePasswordAuth(name)
-{
-	ExternalInit();
-}
-
-bool ExternalPasswordAuth::ExternalInit()
-{
-	const char *ExternalSec = GetName();
-	// Read the configuration
-	Program = config->GetString(ExternalSec, "PasswordProgram", "");
-	return true;
-}
-
-bool ExternalPasswordAuth::GetPassword(const PString & id, PString & passwd)
-{
-	const int BUFFSIZE = 256;
-	char buff[BUFFSIZE] = "";
-	if (Program.IsEmpty()) {
-		PTRACE(1, "GkAuth\tProgram is not defined");
-		return false;
-	}
-
-	procbuf proc(Program + " " + id, ios::in);
-	istream istr(&proc);
-	istr.getline(buff, BUFFSIZE);
-	PTRACE(3, "EXT\tget " << buff);
-	passwd = buff;
-	return true;
-}
-
-namespace {
-	GkAuthCreator<ExternalPasswordAuth> ExternalPasswordAuthCreator("ExternalPasswordAuth");
-}
-
-#endif
-*/
