@@ -9,15 +9,10 @@
 // We also explicitely grant the right to link this code
 // with the OpenH323 library.
 //
-//
-// History:
-//      2001/09/19      initial version (Chih-Wei Huang)
-//      2003/07/15      revision for thread-safed
-//
 //////////////////////////////////////////////////////////////////
 
 #ifndef GKAUTH_H
-#define GKAUTH_H "@(#) $Id: gkauth.h,v 1.30 2006/12/06 16:34:04 zvision Exp $"
+#define GKAUTH_H "@(#) $Id: gkauth.h,v 1.31 2007/03/21 22:30:16 willamowius Exp $"
 
 #include <map>
 #include <list>
