@@ -11,6 +11,18 @@
  * with the OpenH323 library.
  *
  * $Log: gksql.h,v $
+ * Revision 1.10  2006/04/30 09:22:56  willamowius
+ * PTimedMutex patch for PWLib >= 1.9.2
+ *
+ * Revision 1.9  2006/04/14 13:56:19  willamowius
+ * call failover code merged
+ *
+ * Revision 1.1.1.1  2005/11/21 20:19:59  willamowius
+ *
+ *
+ * Revision 1.4  2005/11/15 19:52:56  jan
+ * Michal v1 (works, but on in routed, not proxy mode)
+ *
  * Revision 1.8  2005/04/24 16:39:44  zvision
  * MSVC6.0 compatibility fixed
  *
@@ -31,13 +43,14 @@
  *
  */
 #ifndef GKSQL_H
-#define GKSQL_H "@(#) $Id: gksql.h,v 1.8 2005/04/24 16:39:44 zvision Exp $"
+#define GKSQL_H "@(#) $Id: gksql.h,v 1.10 2006/04/30 09:22:56 willamowius Exp $"
 
 #include <list>
 #include <map>
 #include <vector>
 #include "name.h"
 #include "factory.h"
+#include "pwlib_compat.h"
 
 /** Abstract base class that encapsulates SQL query result.
     Backend specific operations are performed by derived classes.
@@ -459,7 +472,7 @@ private:
 	/// FIFO queue of queries waiting to be executed when there is no idle connections
 	std::list<SQLConnPtr*> m_waitingRequests;
 	/// mutual access to the lists
-	PMutex m_connectionsMutex;
+	PTimedMutex m_connectionsMutex;
 	/// signalled when a connections moves from the busy to the idle list
 	PSyncPoint m_connectionAvailable;
 	/// set to true when destructor is being invoked
