@@ -7,9 +7,6 @@
 // We also explicitely grant the right to link this code
 // with the OpenH323 library.
 //
-// History:
-// 	991129	initial version (Henrik Joerring)
-//
 //////////////////////////////////////////////////////////////////
 
 #include <ptlib.h>
@@ -192,23 +189,6 @@ bool IsLoopback(const PIPSocket::Address & addr)
 	return addr.IsLoopback() != 0;
 }
 
-unsigned MapH225ReasonToQ931Cause(
-	int reason
-	)
-{
-	// from ITU-T Recommendation H.225
-	static unsigned H225ReasonToQ931Cause[] =
-	{
-		34, 47, 3, 16, 88, 111, 38, 42, 28, 41, 17, 31, 16, 31, 20, 31, 47, 127,
-		31, 31, 31, 127
-	};
-	
-	if( reason < 0 || reason > H225_ReleaseCompleteReason::e_tunnelledSignallingRejected )
-		return 0;
-	else
-		return H225ReasonToQ931Cause[reason];
-}
-
 PString GetGUIDString(
 	const H225_GloballyUniqueID& id, /// 128-bit identifier to convert
 	bool fixedLength /// skip leading zeros (false) or not (true)
