@@ -7,14 +7,11 @@
 // We also explicitely grant the right to link this code
 // with the OpenH323 library.
 //
-// History:
-// 	991129	initial version (Henrik Joerring)
-//
 //////////////////////////////////////////////////////////////////
 
 
 #ifndef H323UTIL_H
-#define H323UTIL_H "@(#) $Id: h323util.h,v 1.18 2006/06/22 23:03:30 shorne Exp $"
+#define H323UTIL_H "@(#) $Id: h323util.h,v 1.20 2007/03/21 22:30:16 willamowius Exp $"
 
 #include <ptlib/sockets.h>
 
@@ -92,15 +89,6 @@ PString GetBestAliasAddressString(
 	unsigned primaryTags, /// ORed tag flags (BestAliasTagMask)
 	unsigned secondaryTags = 0 /// ORed tag flags (BestAliasTagMask)
 	);
-	
-/** Map H225_ReleaseCompleteReason code to Q.931 cause value.
-	
-	@return
-	The corresponding Q.931 cause value or 0, if there is no direct mapping.
-*/
-unsigned MapH225ReasonToQ931Cause(
-	int reason /// H225_ReleaseCompleteReason code to map
-	);
 
 /** Return 128-bit globally unique identifier as a string composed of four 
     32-bit hex numbers, with leading zeros skipped or not. This format is 
