@@ -11,7 +11,7 @@
 
 
 #ifndef PWLIB_COMPAT_H
-#define PWLIB_COMPAT_H "@(#) $Id: pwlib_compat.h,v 1.9 2006/10/28 19:51:50 willamowius Exp $"
+#define PWLIB_COMPAT_H "@(#) $Id: pwlib_compat.h,v 1.12 2007/04/20 19:13:00 shorne Exp $"
 
 #include "ptbuildopts.h"
 #include "openh323buildopts.h"
@@ -44,17 +44,18 @@
 // OpenH323 version matching
 #if OPENH323_MAJOR == 1
 	#if OPENH323_MINOR >= 19
-		#ifdef P_DNS
+	  #ifdef P_DNS
 			#define hasSRV 1	// DNS SRV
-		#endif
-		#define OpenH323Factory 1 // OpenH323 Factory Loader Auth
-	#endif
-
-	#if OPENH323_MINOR >= 20
+	  #endif
+	  #if OPENH323_BUILD > 0
+	   #define OpenH323Factory 1 // OpenH323 Factory Loader Auth
+	  #endif
+	  #if OPENH323_BUILD > 4
 		#ifdef H323_H460
 			#define hasH460 1	// H460 support
 		#endif
 		#define h323v6 1		// Version 6 features
+      #endif
 	#endif
 #endif
 
