@@ -13,6 +13,15 @@
  * with the OpenH323 library.
  *
  * $Log: radauth.h,v $
+ * Revision 1.17  2006/04/14 13:56:19  willamowius
+ * call failover code merged
+ *
+ * Revision 1.1.1.1  2005/11/21 20:20:00  willamowius
+ *
+ *
+ * Revision 1.4  2005/11/15 19:52:56  jan
+ * Michal v1 (works, but on in routed, not proxy mode)
+ *
  * Revision 1.16  2005/02/01 14:28:11  zvision
  * Parts of signaling code rewritten
  *
@@ -93,7 +102,7 @@
 #if HAS_RADIUS
 
 #ifndef __RADAUTH_H
-#define __RADAUTH_H "@(#) $Id: radauth.h,v 1.16 2005/02/01 14:28:11 zvision Exp $"
+#define __RADAUTH_H "@(#) $Id: radauth.h,v 1.17 2006/04/14 13:56:19 willamowius Exp $"
 
 #include "gkauth.h"
 
