@@ -11,6 +11,27 @@
  * with the OpenH323 library.
  *
  * $Log: radproto.cxx,v $
+ * Revision 1.30  2006/07/06 15:25:13  willamowius
+ * set all deleted pointers to NULL (most probably more than needed)
+ *
+ * Revision 1.29  2006/04/14 13:56:19  willamowius
+ * call failover code merged
+ *
+ * Revision 1.2  2005/12/16 14:16:32  zvision
+ * Removed incorrect C/C++ language constructs
+ *
+ * Revision 1.1.1.1  2005/11/21 20:19:57  willamowius
+ *
+ *
+ * Revision 1.4  2005/11/15 19:52:56  jan
+ * Michal v1 (works, but on in routed, not proxy mode)
+ *
+ * Revision 1.27  2005/05/18 20:56:01  zvision
+ * Better checking and reporting of network errors
+ *
+ * Revision 1.26  2005/05/18 14:23:33  zvision
+ * Better error reporting on socket allocation
+ *
  * Revision 1.25  2005/04/24 16:39:44  zvision
  * MSVC6.0 compatibility fixed
  *
@@ -1374,10 +1395,14 @@ bool RadiusPDU::EncryptPasswords(
 		buf2ptr += 4;
 	} else {
 		// dword aligned data
-		*buf1ptr++ = *buf1ptr ^ *buf2ptr++;
-		*buf1ptr++ = *buf1ptr ^ *buf2ptr++;
-		*buf1ptr++ = *buf1ptr ^ *buf2ptr++;
-		*buf1ptr++ = *buf1ptr ^ *buf2ptr++;
+		*buf1ptr = *buf1ptr ^ *buf2ptr++;
+		++buf1ptr;
+		*buf1ptr = *buf1ptr ^ *buf2ptr++;
+		++buf1ptr;
+		*buf1ptr = *buf1ptr ^ *buf2ptr++;
+		++buf1ptr;
+		*buf1ptr = *buf1ptr ^ *buf2ptr++;
+		++buf1ptr;
 	}
 
 	// encrypt remaining 16 byte blocks of the password
@@ -1400,10 +1425,14 @@ bool RadiusPDU::EncryptPasswords(
 			buf2ptr += 4;
 		} else {
 			// dword aligned data
-			*buf1ptr++ = *buf1ptr ^ *buf2ptr++;
-			*buf1ptr++ = *buf1ptr ^ *buf2ptr++;
-			*buf1ptr++ = *buf1ptr ^ *buf2ptr++;
-			*buf1ptr++ = *buf1ptr ^ *buf2ptr++;
+			*buf1ptr = *buf1ptr ^ *buf2ptr++;
+			++buf1ptr;
+			*buf1ptr = *buf1ptr ^ *buf2ptr++;
+			++buf1ptr;
+			*buf1ptr = *buf1ptr ^ *buf2ptr++;
+			++buf1ptr;
+			*buf1ptr = *buf1ptr ^ *buf2ptr++;
+			++buf1ptr;
 		}
 	}
 	
@@ -1434,7 +1463,14 @@ RadiusSocket::RadiusSocket(
 	m_isReading(false), m_nestedCount(0), 
 	m_idCacheTimeout(RadiusClient::DefaultIdCacheTimeout)
 {
-	Listen(0, port);
+	if (!Listen(0, port)) {
+		PTRACE(1, "RADIUS\tCould not bind socket to the port " << port
+			<< " - error " << GetErrorCode(PSocket::LastGeneralError) << '/'
+			<< GetErrorNumber(PSocket::LastGeneralError) << ": " 
+			<< GetErrorText(PSocket::LastGeneralError)
+			);
+		Close();
+	}
 	
 	int i;
 	PRandom random;
@@ -1463,7 +1499,14 @@ RadiusSocket::RadiusSocket(
 	m_isReading(false), m_nestedCount(0),
 	m_idCacheTimeout(RadiusClient::DefaultIdCacheTimeout)
 {
-	Listen(addr, 0, port);
+	if (!Listen(addr, 0, port)) {
+		PTRACE(1, "RADIUS\tCould not bind socket to " << addr << ':' << port
+			<< " - error " << GetErrorCode(PSocket::LastGeneralError) << '/'
+			<< GetErrorNumber(PSocket::LastGeneralError) << ": " 
+			<< GetErrorText(PSocket::LastGeneralError)
+			);
+		Close();
+	}
 	
 	int i;
 	PRandom random;
@@ -1596,8 +1639,8 @@ bool RadiusSocket::MakeRequest(
 	BOOL result = WriteTo(request, length, serverAddress, serverPort);
 	if (!result)
 		PTRACE(5, "RADIUS\tError sending UDP packet ("
-			<< GetErrorCode(LastWriteError) << ':'
-			<< GetErrorNumber(LastWriteError) << ':'
+			<< GetErrorCode(LastWriteError) << '/'
+			<< GetErrorNumber(LastWriteError) << ": "
 			<< GetErrorText(LastWriteError) << " (id:" << (PINDEX)id << ')'
 			);
 	m_writeMutex.Signal();
@@ -1619,11 +1662,12 @@ bool RadiusSocket::MakeRequest(
 					PTRACE(6, "RADIUS\tTimed out reading socket " << *this);
 				else
 					PTRACE(5, "RADIUS\tError reading socket " << *this
-						<< " (" << GetErrorCode(LastReadError) << ':'
-						<< GetErrorNumber(LastReadError) << ':'
+						<< " (" << GetErrorCode(LastReadError) << '/'
+						<< GetErrorNumber(LastReadError) << ": "
 						<< GetErrorText(LastReadError) << ')'
 						);
 				delete response;
+				response = NULL;
 				break;
 			}
 			
@@ -1636,12 +1680,14 @@ bool RadiusSocket::MakeRequest(
 					<< bytesRead << ')'
 					);
 				delete response;
+				response = NULL;
 				continue;
 			}
 	
 			if (!response->IsValid()) {
 				PTRACE(5, "RADIUS\tReceived packet is not a valid Radius PDU");
 				delete response;
+				response = NULL;
 				continue;
 			}
 				
@@ -1652,6 +1698,7 @@ bool RadiusSocket::MakeRequest(
 					<< (PINDEX)newId
 					);
 				delete response;
+				response = NULL;
 				continue;
 			}
 				
@@ -1663,6 +1710,7 @@ bool RadiusSocket::MakeRequest(
 					<< (PINDEX)newId << ')'
 					);
 				delete response;
+				response = NULL;
 				continue;
 			}
 
@@ -1672,6 +1720,7 @@ bool RadiusSocket::MakeRequest(
 					<< remoteAddress << ':' << remotePort
 					);
 				delete response;
+				response = NULL;
 				continue;
 			}
 			
@@ -1683,7 +1732,7 @@ bool RadiusSocket::MakeRequest(
 				m_isReading = false;
 
 				if (m_nestedCount)
-					for (PINDEX i = 0, j = m_oldestId; i < 256; i++, j = (++j) & 0xff)
+					for (PINDEX i = 0, j = m_oldestId; i < 256; i++, j = (j + 1) & 0xff)
 						if (m_readSyncPointIndices[j] != P_MAX_INDEX
 							&& m_readSyncPoints[m_readSyncPointIndices[j] & 0xff] != NULL)
 						{
@@ -1692,6 +1741,7 @@ bool RadiusSocket::MakeRequest(
 						}
 					
 				delete requestInfo;
+				requestInfo = NULL;
 				return true;
 			} else if(m_readSyncPointIndices[newId] != P_MAX_INDEX
 				&& m_readSyncPoints[m_readSyncPointIndices[newId]] != NULL) {
@@ -1713,6 +1763,7 @@ bool RadiusSocket::MakeRequest(
 				if (m_nestedCount)
 					m_nestedCount--;
 				delete requestInfo;
+				requestInfo = NULL;
 				return true;
 			}
 
@@ -1751,7 +1802,7 @@ bool RadiusSocket::MakeRequest(
 			m_isReading = false;
 
 			if (m_nestedCount)
-				for (PINDEX i = m_oldestId, j = 0; j < 256; j++, i = (++i) & 0xff)
+				for (PINDEX i = m_oldestId, j = 0; j < 256; j++, i = (i + 1) & 0xff)
 					if (m_readSyncPointIndices[i] != P_MAX_INDEX
 						&& m_readSyncPoints[m_readSyncPointIndices[i] & 0xff] != NULL)
 					{
@@ -1762,6 +1813,7 @@ bool RadiusSocket::MakeRequest(
 	}
 
 	delete requestInfo;
+	requestInfo = NULL;
 	return result ? true : false;
 }
 
@@ -1779,8 +1831,8 @@ bool RadiusSocket::SendRequest(
 		return true;
 		
 	PTRACE(5, "RADIUS\tError sending UDP packet ("
-		<< GetErrorCode(LastWriteError) << ':'
-		<< GetErrorNumber(LastWriteError) << ':'
+		<< GetErrorCode(LastWriteError) << '/'
+		<< GetErrorNumber(LastWriteError) << ": "
 		<< GetErrorText(LastWriteError) << " (id:" 
 		<< (PINDEX)request->GetId() << ')'
 		);
@@ -2171,6 +2223,7 @@ bool RadiusClient::MakeRequest(
 #endif
 			if (!OnReceivedPDU(*response)) {
 				delete response;
+				response = NULL;
 				continue;
 			}
 			
