@@ -15,7 +15,7 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef YASOCKET_H
-#define YASOCKET_H "@(#) $Id: yasocket.h,v 1.21 2006/06/08 08:28:49 willamowius Exp $"
+#define YASOCKET_H "@(#) $Id: yasocket.h,v 1.22 2007/01/23 13:16:20 zvision Exp $"
 
 #include <list>
 #include <vector>
@@ -295,12 +295,12 @@ public:
 #else
 	bool IsReadable(int milisec = 0)
 	{
-		return SocketSelectList(self).Select(SocketSelectList::Read, milisec);
+		return self->IsOpen() && SocketSelectList(self).Select(SocketSelectList::Read, milisec);
 	}
 
 	bool IsWriteable(int milisec = 0)
 	{
-		return SocketSelectList(self).Select(SocketSelectList::Write, milisec);
+		return self->IsOpen() && SocketSelectList(self).Select(SocketSelectList::Write, milisec);
 	}
 #endif
 
